@@ -3,7 +3,7 @@ import argparse
 from fontTools.ttLib import TTFont  # type: ignore
 
 from .bridge import ttfont_glyph_to_skia_path
-from .stringbuilder import path_header
+from .stringbuilder import report_header
 from .validators import validate_fontpath, validate_glyph_in_font
 
 
@@ -24,5 +24,5 @@ def report_run(args: argparse.Namespace) -> None:
     skia_path = ttfont_glyph_to_skia_path(glyphname, tt)
 
     # Path dump from skia
-    print(path_header(f"'{glyphname}' path"))
+    print(report_header(f"'{glyphname}' path"))
     skia_path.dump()
